# API Reference

Technical reference for the `lst_tools` package.

## Modules

*Autogenerated from source docstrings.*

- [Grid & Flow](core.md): Core data structures for grid and flow data
- [Config](config.md): Configuration management and schema
- [Convert](convert.md): Format conversion (HDF5 to LASTRAC)
- [Setup](setup.md): LST calculation setup (parsing, tracking, spectra)
- [Processing](processing.md): Post-processing of LST results
- [Data I/O](data-io.md): File readers and writers
- [Geometry](geometry.md): Surface geometry computations
- [HPC](hpc.md): HPC job script generation
